Crate batch_mode_token_expansion_traits

Crate batch_mode_token_expansion_traits 

Structs

SystemMessageHeader

Traits

AxisDescription
A trait that describes the axis in textual form. Implementations usually associate a descriptive string per enum variant, used for instructing the end user or prompting an LLM how to expand that axis.
AxisName
A trait that describes the name of an axis. Implementations usually associate one distinct axis name string per enum variant.
ExpandedToken
This trait marks types which represent expanded tokens. It is helpful to have a way to treat them generically
GetTokenExpansionAxes
IntoLanguageModelQueryString
SystemMessageGoal
A trait that describes the system message goal for a given axis set. This is typically implemented for the entire enum and returns a single, static system message goal string for the entire type.
TokenExpander
This trait we use as a generic expander of tokens. It leverages a collection of TokenExpanderAxes and has its implementation typically automatically generated by the TokenExpansionAxis proc macro
TokenExpansionAxis
Trait defining the capabilities of a TokenExpansionAxis.

Type Aliases

TokenExpansionAxes